OC.L10N.register(
    "core",
    {
    "Please select a file." : "Mesedez, hautatu fitxategia.",
    "File is too big" : "Fitxategia handiegia da",
    "Invalid file provided" : "Baliogabeko fitxategia",
    "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "An error occurred. Please contact your admin." : "Errore bat gertatu da. Mesedez jarri harremanetan zure administratzailearekin.",
    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik, saiatu berriro",
    "No crop data provided" : "Ez da ebaketarako daturik zehaztu",
    "No valid crop data provided" : "Ebaketarako datu baliogabea",
    "Crop is not square" : "Ebaketa ez da karratua",
    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
    "Could not reset password because the token expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
    "Could not reset password because the token does not match" : "Ezin izan da pasahitza berrezarri tokena ez datorrelako bat",
    "%s password changed successfully" : "%s pasahitza behar bezala aldatu da",
    "%s password reset" : "%s pasahitza berrezarri",
    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
    "Download / View" : "Deskargatu / Ikusi",
    "Recipients can view or download contents." : "Hartzaileek edukiak ikusi edo jaitsi ditzakete.",
    "Download / View / Upload" : "Deskargatu / Ikusi / Kargatu",
    "Recipients can view, download, edit, delete and upload contents." : "Hartzaileek edukiak jaitsi, editatu, ezabatu eta igo ditzakete.",
    "Upload only" : "Kargatu bakarrik",
    "Receive files from multiple recipients without revealing the contents of the folder." : "Hainbat hartzaileengandik fitxategiak jaso karpeten edukiak erakutsi gabe.",
    "Preparing update" : "Eguneraketa prestatzen",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Konponketa abisua:",
    "Repair error: " : "Konponketa errorea:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Mesedez, erabili komando lerroko eguneraketa, modu automatikoa desgaitua dago config.php fitxategian",
    "[%d / %d]: Checking table %s" : "[%d / %d]: %s Taula baieztatzen",
    "Turned on maintenance mode" : "Mantenu modua gaitu da",
    "Turned off maintenance mode" : "Mantenu modua desgaitu da",
    "Maintenance mode is kept active" : "Mantentze-modua aktibo dago",
    "Updating database schema" : "Datu-base eskema eguneratzen",
    "Updated database" : "Datu basea eguneratu da",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Datu-base eskema eguneratu daiteken baieztatzen (dabu-base tamainaren arabera denbora luzea eraman dezake honek)",
    "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
    "Checking updates of apps" : "Aplikazioentzat eguneraketak baieztatzen",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s-en datubase eskema eguneratu daitekeen baieztatzen (datubasearen tamainaren arabera denbora luzea eman dezake honek)",
    "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
    "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
    "Set log level to debug" : "Log maila arazketa gisa jarri",
    "Reset log level" : "Log maila berrezarri",
    "Starting code integrity check" : "Kode osotasun baieztapena hasten",
    "Finished code integrity check" : "Kode osotasun baieztapena amaituta",
    "%s (3rdparty)" : "%s (3garrena)",
    "%s (incompatible)" : "%s (bateraezina)",
    "Following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
    "Already up to date" : "Dagoeneko martxan",
    "Sunday" : "Igandea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sun." : "ig.",
    "Mon." : "al.",
    "Tue." : "ar.",
    "Wed." : "az.",
    "Thu." : "og.",
    "Fri." : "ol.",
    "Sat." : "lr.",
    "Su" : "Ig",
    "Mo" : "Al",
    "Tu" : "Ar",
    "We" : "Az",
    "Th" : "Og",
    "Fr" : "Ol",
    "Sa" : "La",
    "January" : "Urtarrila",
    "February" : "Otsaila",
    "March" : "Martxoa",
    "April" : "Apirila",
    "May" : "Maiatza",
    "June" : "Ekaina",
    "July" : "Uztaila",
    "August" : "Abuztua",
    "September" : "Iraila",
    "October" : "Urria",
    "November" : "Azaroa",
    "December" : "Abendua",
    "Jan." : "urt.",
    "Feb." : "ots.",
    "Mar." : "mar.",
    "Apr." : "api.",
    "May." : "mai.",
    "Jun." : "eka.",
    "Jul." : "uzt.",
    "Aug." : "abu.",
    "Sep." : "ira.",
    "Oct." : "urr.",
    "Nov." : "aza.",
    "Dec." : "abe.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Arazoak egon dira kodearen osotasun egiaztatzearekin. Xehetasun gehiago...</a>",
    "Settings" : "Ezarpenak",
    "Problem loading page, reloading in 5 seconds" : "Arazoa orria kargatzen, 5 segundo barru birkargatuko da",
    "Saving..." : "Gordetzen...",
    "Dismiss" : "Baztertu",
    "seconds ago" : "segundu",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Zure pasahitza berrezartzeko lotura zure postara bidalia izan da.<br>Ez baduzu arrazoizko denbora epe batean jasotzen begiratu zure zabor-posta karpetan.<br>Hor ere ez badago kudeatzailearekin harremanetan jarri.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Zure fitxategiak enkriptaturik daude. Ez baduzu berreskuratze gakoa gaitzen pasahitza berrabiaraztean ez da zure fitxategiak berreskuratzeko modurik egongo. <br />Zer egin ziur ez bazaude kudeatzailearekin harremanetan ipini jarraitu aurretik.<br /> Ziur zaude aurrera jarraitu nahi duzula?",
    "I know what I'm doing" : "Badakit zertan nabilen",
    "Password can not be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Mesedez jarri harremetan zure administradorearekin.",
    "Error adding {addItem}: {addItem} already exists" : "{addItem} gehitzean errorea: {addItem} dagoeneko bada",
    "No" : "Ez",
    "Yes" : "Bai",
    "Choose" : "Aukeratu",
    "Error loading file picker template: {error}" : "Errorea fitxategi hautatzaile txantiloiak kargatzerakoan: {error}",
    "Ok" : "Ados",
    "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
    "read-only" : "irakurtzeko-soilik",
    "_{count} file conflict_::_{count} file conflicts_" : ["fitxategi {count}ek konfliktua sortu du","{count} fitxategik konfliktua sortu dute"],
    "One file conflict" : "Fitxategi batek konfliktua sortu du",
    "New Files" : "Fitxategi Berriak",
    "Already existing files" : "Dagoeneko existitzen diren fitxategiak",
    "Which files do you want to keep?" : "Ze fitxategi mantendu nahi duzu?",
    "If you select both versions, the copied file will have a number added to its name." : "Bi bertsioak hautatzen badituzu, kopiatutako fitxategiaren izenean zenbaki bat atxikituko zaio.",
    "Cancel" : "Ezeztatu",
    "Continue" : "Jarraitu",
    "(all selected)" : "(denak hautatuta)",
    "({count} selected)" : "({count} hautatuta)",
    "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloiak kargatzerakoan",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Zure web zerbitzaria ez dago ondo ezarrita WebDAV interfazea apurtuta dagoela dirudielako.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Zure web zerbitzaria ez dago ondo ezarrita \"{url}\" ebazteko. Xehetasun gehiago aurkitu daiteke gure <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentazioan</a>.",
    "Error occurred while checking server setup" : "Errore bat gertatu da zerbitzariaren konfigurazioa egiaztatzerakoan.",
    "Shared" : "Elkarbanatuta",
    "Shared with {recipients}" : "{recipients}-rekin partekatua.",
    "Error" : "Errorea",
    "Error while sharing" : "Errore bat egon da elkarbanatzean",
    "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
    "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
    "Expiration" : "Iraungitzea",
    "Remove link" : "Esteka ezabatu",
    "Link" : "Esteka",
    "Create public link" : "Esteka publikoa sortu",
    "Edit" : "Editatu",
    "Remove" : "Ezabatu",
    "Copy to clipboard" : "Kopiatu arbelera",
    "Anyone with the link has access to the file/folder" : "Esteka duen edonork atzitu dezake fitxategi/karpeta",
    "Copied!" : "Kopiatua!",
    "Not supported!" : "Euskarririk ez!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "Choose a password" : "Aukeratu pasahitza",
    "Password required" : "Pasahitza beharrezkoa",
    "Link name" : "Estekaren izena",
    "Name" : "Izena",
    "Filename" : "Fitxategiaren izena",
    "Password" : "Pasahitza",
    "Share" : "Elkarbanatu",
    "Save" : "Gorde",
    "Remove password" : "Pasahitza ezabatu",
    "Email link to person" : "Postaz bidali lotura ",
    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
    "group" : "taldea",
    "notify by email" : "jakinarazi eposta bidez",
    "Unshare" : "Ez elkarbanatu",
    "can share" : "elkarbana dezake",
    "can edit" : "editatu dezake",
    "create" : "sortu",
    "change" : "aldatu",
    "delete" : "ezabatu",
    "access control" : "sarrera kontrola",
    "No users found for {search}" : "Ez da erabiltzailerik aurkitu {search} bilaketan",
    "An error occurred. Please try again" : "Errorea eman da. Saiatu berriz mesedez",
    "User" : "Erabiltzailea",
    "Group" : "Taldea",
    "User and Groups" : "Erabiltzaile eta Taldeak",
    "Public Links" : "Esteka Publikoak",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partekatu beste ownClud-en jendearekin sintaxi honekin erabiltzaleizena@adibidea.com/owncloud",
    "Delete" : "Ezabatu",
    "Rename" : "Berrizendatu",
    "Collaborative tags" : "Kolaboraziorako etiketak",
    "The object type is not specified." : "Objetu mota ez dago zehaztuta.",
    "Enter new" : "Sartu berria",
    "Add" : "Gehitu",
    "Edit tags" : "Editatu etiketak",
    "Error loading dialog template: {error}" : "Errorea elkarrizketa txantiloia kargatzean: {errorea}",
    "No tags selected for deletion." : "Ez dira ezabatzeko etiketak hautatu.",
    "unknown text" : "testu ezezaguna",
    "Hello world!" : "Kaixo Mundua!",
    "sunny" : "eguzkitsua",
    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
    "Hello {name}" : "Kaixo {name}",
    "_download %n file_::_download %n files_" : ["%n fitxategia jaitsi","jaitsi %n fitxategiak"],
    "An error occurred." : "Errore bat gertatu da.",
    "Please reload the page." : "Mesedez birkargatu orria.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Eguneraketa ez da ongi egin. Mesedez egin arazoaren txosten bat <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud komunitatearentzako</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Eguneraketa ongi egin da. Orain zure ownClouderea berbideratua izango zara.",
    "Searching other places" : "Beste lekuak bilatzen",
    "No search results in other folders" : "Ez da bilaketaren emaitzik lortu beste karpetatan",
    "Personal" : "Pertsonala",
    "Users" : "Erabiltzaileak",
    "Apps" : "Aplikazioak",
    "Admin" : "Admin",
    "Help" : "Laguntza",
    "Access forbidden" : "Sarrera debekatuta",
    "File not found" : "Ez da fitxategia aurkitu",
    "The specified document has not been found on the server." : "Zehaztutako dokumentua ez da zerbitzarian aurkitu.",
    "You can click here to return to %s." : "Hemen klika dezakezu %sra itzultzeko.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Kaixo,\n\n%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s\n\n",
    "The share will expire on %s." : "Elkarbanaketa %s-n iraungiko da.",
    "Cheers!" : "Ongi izan!",
    "Internal Server Error" : "Zerbitzariaren Barne Errorea",
    "The server encountered an internal error and was unable to complete your request." : "Zerbitzariak barne errore bat izan du eta ez da gai izan zure eskaria osatzeko.",
    "Technical details" : "Arazo teknikoak",
    "Remote Address: %s" : "Urruneko Helbidea: %s",
    "Request ID: %s" : "Eskariaren IDa: %s",
    "Code: %s" : "Kodea: %s",
    "Message: %s" : "Mezua: %s",
    "File: %s" : "Fitxategia: %s",
    "Line: %s" : "Lerroa: %s",
    "Trace" : "Arrastoa",
    "Imprint" : "Imprint",
    "Privacy Policy" : "Pribatasun Politika",
    "Create an <strong>admin account</strong>" : "Sortu <strong>kudeatzaile kontu<strong> bat",
    "Username" : "Erabiltzaile izena",
    "Storage & database" : "Biltegia & datubasea",
    "Data folder" : "Datuen karpeta",
    "Configure the database" : "Konfiguratu datu basea",
    "Only %s is available." : "Soilik %s dago eskuragarri.",
    "Database user" : "Datubasearen erabiltzailea",
    "Database password" : "Datubasearen pasahitza",
    "Database name" : "Datubasearen izena",
    "Database tablespace" : "Datu basearen taula-lekua",
    "Database host" : "Datubasearen hostalaria",
    "Finish setup" : "Bukatu konfigurazioa",
    "Finishing …" : "Bukatzen...",
    "Need help?" : "Laguntza behar al duzu?",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo,<br><br>%s-ek <strong>%s</strong> zurekin partekatu duela jakin dezazun.<br><a href=\"%s\">Ikusi ezazu!</a><br><br>",
    "Menu" : "Menua",
    "Log out" : "Saioa bukatu",
    "Search" : "Bilatu",
    "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
    "Please contact your administrator." : "Mesedez jarri harremetan zure administradorearekin.",
    "Login" : "Saio hasiera",
    "Alternative Logins" : "Beste erabiltzaile izenak",
    "Use the following link to reset your password: {link}" : "Eribili hurrengo lotura zure pasahitza berrezartzeko: {link}",
    "New password" : "Pasahitz berria",
    "New Password" : "Pasahitz Berria",
    "Confirm Password" : "Pasahitza baieztatu",
    "Reset password" : "Berrezarri pasahitza",
    "This ownCloud instance is currently in single user mode." : "ownCloud instantzia hau erabiltzaile bakar moduan dago.",
    "This means only administrators can use the instance." : "Honek administradoreak bakarrik erabili dezakeela esan nahi du.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu hau irauten badu edo bat-batean agertu bada.",
    "Thank you for your patience." : "Milesker zure patzientziagatik.",
    "You are accessing the server from an untrusted domain." : "Zerbitzaria domeinu ez fidagarri batetik eskuratzen ari zara.",
    "The theme %s has been disabled." : "%s gaia desgaitu da.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia duzula.",
    "Start update" : "Hasi eguneraketa",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handien itxarote-denbora saihesteko, ondoko komandoa exekuta dezakezu instalazio direktoriotik:",
    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean."
},
"nplurals=2; plural=(n != 1);");
